==> hy-0.9.10.tar.gz: hy-0.9.10/hy/__init__.py <==
# Copyright (c) 2013 Paul Tagliamonte <paultag@debian.org>
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.


__appname__ = "hy"
__version__ = "0.9.10"


from hy.models.expression import HyExpression  # NOQA
from hy.models.integer import HyInteger  # NOQA
from hy.models.keyword import HyKeyword  # NOQA
from hy.models.complex import HyComplex  # NOQA
from hy.models.string import HyString  # NOQA
from hy.models.symbol import HySymbol  # NOQA
from hy.models.float import HyFloat  # NOQA
from hy.models.dict import HyDict  # NOQA
from hy.models.list import HyList  # NOQA


import hy.importer  # NOQA
# we import for side-effects.

==> hy-0.9.12.tar.gz: hy-0.9.12/hy/__init__.py <==
# Copyright (c) 2013 Paul Tagliamonte <paultag@debian.org>
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.


from hy.version import __version__, __appname__  # NOQA


from hy.models.expression import HyExpression  # NOQA
from hy.models.lambdalist import HyLambdaListKeyword  # NOQA
from hy.models.integer import HyInteger  # NOQA
from hy.models.keyword import HyKeyword  # NOQA
from hy.models.complex import HyComplex  # NOQA
from hy.models.string import HyString  # NOQA
from hy.models.symbol import HySymbol  # NOQA
from hy.models.float import HyFloat  # NOQA
from hy.models.dict import HyDict  # NOQA
from hy.models.list import HyList  # NOQA


import hy.importer  # NOQA
# we import for side-effects.
